/**
 * Copyright (C) 2000 Frdric Laurent
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * @version 0.1, November 11 2000
 * @author <a href="mailto:flr@free.fr">Frederic Laurent</a>
 * @since JDK 1.2
 */

package SwingAdapter;

import javax.swing.ListCellRenderer;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.border.Border;
import javax.swing.UIManager;
import java.awt.Graphics;
import javax.swing.border.EmptyBorder;
import java.awt.Color;
import java.awt.Insets;
import java.awt.FontMetrics;
import java.awt.Component;
import java.util.StringTokenizer;
import java.io.File;


public class FindListRenderer extends JLabel implements ListCellRenderer {
     // This is the only method defined by ListCellRenderer.  We just
     // reconfigure the Jlabel each time we're called.
	
	protected static Border noFocusBorder;
	protected FontMetrics fm = null;
	protected Insets insets = new Insets(0,0,0,0);
	protected Color matchColor = null;
	
	public FindListRenderer() {
		super();
		this.noFocusBorder = new EmptyBorder(1, 1, 1, 1);
		setBorder(this.noFocusBorder);
		setOpaque(true);
		this.matchColor = new Color(153,0,0);
	}

	public Component getListCellRendererComponent(
												  JList list,
												  Object value,            // value to display
												  int index,               // cell index
												  boolean isSelected,      // is the cell selected
												  boolean cellHasFocus)    // the list and the cell have the focus
	{
		String s = value.toString();
		setText(s);
		
		setBackground(isSelected ? list.getSelectionBackground() : list.getBackground());
		setForeground(isSelected ? list.getSelectionForeground() : list.getForeground());

		setFont(list.getFont());
		setBorder((cellHasFocus) ? UIManager.getBorder("List.focusCellHighlightBorder") : this.noFocusBorder);
		return this;
	}
	
	public void paint(Graphics g) {

		this.fm = g.getFontMetrics();
		
		g.setColor(getBackground());
		g.fillRect(0,0,getWidth(),getHeight());
		getBorder().paintBorder(this,g,0,0,getWidth(),getHeight());
		g.setFont(getFont());
		this.insets = getInsets();
		int x = this.insets.left;
		int y = this.insets.top+this.fm.getAscent();


		String val = getText();
		int    pos = val.lastIndexOf(File.separator);
		String path = val.substring(0, pos+1);
		
		g.setColor(Color.black);		
		g.drawString(path,x,y);
		x += this.fm.stringWidth(path);
		
		g.setColor(this.matchColor);		
		g.drawString(val.substring(pos+1, val.length()),x,y);
	}
}





